//     Author: Maurizio Loreti, aka MLO or (HAM) I3NOO
//     Work:   University of Padova - Department of Physics
//             Via F. Marzolo, 8 - 35131 PADOVA - Italy
//     Phone:  +39 (049) 827-7216   FAX: +39 (049) 827-7102
//     EMail:  loreti@pd.infn.it
//     WWW:    http://www.pd.infn.it/~loreti/mlo.html
//
// -------------------------------------------------------------------
// Declarations for a "file information" class; the definitions are in
// "fid.cxx" .
// -------------------------------------------------------------------
// $Id: fid.hh,v 1.2 2005/06/06 07:39:51 loreti Exp $
// -------------------------------------------------------------------

#ifndef FID_HH_
#define FID_HH_

#include <string>
#include <ctime>

extern "C" {
  #include <sys/types.h>
  #include <sys/stat.h>
  #include <unistd.h>
}

// A class "fileInfo", to store the informations to be watched for a
// given file.
//
// Data:
// - file name, file modes, file owner (UID and GID), file size (in
//   bytes), modification time, file content.
//
// Methods:
// - constructor, from a file name;
// - destructor;
// - statFile (internal): to retrieve and store all the data (except
//   the file content) using a call to stat(2);
// - checkStat: to check (and, if needed, restore) file mode and/or
//   file owner;
// - update: to restore the watched file;
// - accessors, to retrieve file content, modification time, file name
//   and file size.
//
// N.B.: copy constructor and assignment operator are declared private
//       but never defined, in order to prevent their use.

class fileInfo {
private:
  std::string name_;
  mode_t      mode_;
  uid_t       uid_;
  gid_t       gid_;
  off_t       size_;
  time_t      mtime_;
  char *      content_;

  void statFile();

  fileInfo(const fileInfo &);
  fileInfo & operator = (const fileInfo &);

public:
  fileInfo(const std::string & name);
  ~fileInfo() { delete [] content_; }

  void                checkStat(int, mode_t, uid_t, gid_t) const;
  void                update();

  const char *        getContent() const { return content_; }
  const time_t &      getMtime()   const { return mtime_; }
  const std::string & getName()    const { return name_; }
  off_t               getSize()    const { return size_; }
};

#endif // FID_HH_
